betty.extension.webpack package - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.extension.webpack package

## Subpackages

- betty.extension.webpack.jinja2 package
  - Submodules
    - betty.extension.webpack.jinja2.filter module
      - `filter_webpack_entry_point_js()`
  - Module contents

## Submodules

- betty.extension.webpack.build module
  - `Builder`
    - `Builder.__init__()`
    - `Builder.build()`
  - `webpack_build_id()`

## Module contents

Integrate Betty with Webpack.

This module is internal.

class betty.extension.webpack.PrebuiltAssetsRequirement

  Bases: `Requirement`

  Check if prebuilt assets are available.

  async is_met() → bool

    Check if the requirement is met.

  async summary() → Localizable

    Get the requirement’s human-readable summary.

final class betty.extension.webpack.Webpack

  Bases: `Extension`, `CssProvider`, `Jinja2Provider`

  Integrate Betty with Webpack.

  This is internal. It MAY be used anywhere in Betty’s source code, but MUST NOT be used by third-party code.

  classmethod assets_directory_path() → Path

    Return the path on disk where the extension’s assets are located.

    This may be anywhere in your Python package.

  build_requirement() → Requirement

    Get the requirement that must be satisfied for Webpack builds to be available.

  classmethod enable_requirement() → Requirement

    Define the requirement for this extension to be enabled.

    This defaults to the extension’s dependencies.

  property filters: dict[str, Callable[[...], Any]]

    Jinja2 filters provided by this extension.

    Keys are filter names, and values are the filters themselves.

  new_context_vars() → dict[str, Any]

    Create new variables for a new `jinja2.runtime.Context`.

    Keys are the variable names, and values are variable values.

  classmethod plugin_id() → MachineName

    Get the plugin ID.

    IDs are unique per plugin type:

    - A plugin repository MUST at most have a single plugin for any ID.

    - Different plugin repositories MAY each have a plugin with the same ID.

  classmethod plugin_label() → Localizable

    Get the human-readable short plugin label.

  async prebuild(job_context: Context) → None

    Prebuild the Webpack assets.

  property public_css_paths: list[str]

    The public URL paths to the CSS files to include in each HTML page.

  register_event_handlers(registry: EventHandlerRegistry) → None

    Register event handlers with the project.

class betty.extension.webpack.WebpackEntryPointProvider

  Bases: `ABC`

  An extension that provides Webpack entry points.

  abstract webpack_entry_point_cache_keys() → Sequence[str]

    Get the keys that make a Webpack build for this provider unique.

    Providers that can be cached regardless may `return ()`.

  abstract classmethod webpack_entry_point_directory_path() → Path

    Get the path to the directory with the entry point assets.

    The directory must include at least a `package.json` and `main.ts`.